@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -63,9 +64,7 @@ void FilterImporterAbstract::appendFilter(MailCommon::MailFilter *filter)
     }
 }
 
-void FilterImporterAbstract::createFilterAction(MailCommon::MailFilter *filter,
-        const QString &actionName,
-        const QString &value)
+void FilterImporterAbstract::createFilterAction(MailCommon::MailFilter *filter, const QString &actionName, const QString &value)
 {
     if (!actionName.isEmpty()) {
         FilterActionDesc *desc = MailCommon::FilterManager::filterActionDict()->value(actionName);
