@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -43,7 +43,7 @@ public:
     {
     }
 
-    Akonadi::ChangeRecorder *mMonitor;
+    Akonadi::ChangeRecorder *mMonitor = nullptr;
 };
 
 FolderCollectionMonitor::FolderCollectionMonitor(Akonadi::Session *session, QObject *parent)
@@ -91,7 +91,7 @@ void FolderCollectionMonitor::expireAllCollection(const QAbstractItemModel *mode
         const QModelIndex index = model->index(row, 0, parentIndex);
         const Akonadi::Collection collection
             = model->data(
-            index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                  index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         if (!collection.isValid() || Util::isVirtualCollection(collection)) {
             continue;
@@ -100,7 +100,7 @@ void FolderCollectionMonitor::expireAllCollection(const QAbstractItemModel *mode
         bool mustDeleteExpirationAttribute = false;
         MailCommon::ExpireCollectionAttribute *attr
             = MailCommon::Util::expirationCollectionAttribute(
-            collection, mustDeleteExpirationAttribute);
+                  collection, mustDeleteExpirationAttribute);
 
         if (attr->isAutoExpire()) {
             MailCommon::Util::expireOldMessages(collection, immediate);
