@@ -125,8 +125,8 @@ void FolderTreeView::readConfig()
     setIconSize(QSize(iIconSize, iIconSize));
     mToolTipDisplayPolicy
         = static_cast<FolderTreeWidget::ToolTipDisplayPolicy>(
-        myGroup.readEntry("ToolTipDisplayPolicy",
-                          static_cast<int>(FolderTreeWidget::DisplayAlways)));
+              myGroup.readEntry("ToolTipDisplayPolicy",
+                                static_cast<int>(FolderTreeWidget::DisplayAlways)));
 
     Q_EMIT changeTooltipsPolicy(mToolTipDisplayPolicy);
 
@@ -145,14 +145,16 @@ void FolderTreeView::slotHeaderContextMenuRequested(const QPoint &pnt)
     // the menu for the columns
     QMenu menu;
     QAction *act = nullptr;
-    menu.addSection(i18n("View Columns"));
     const int nbColumn = header()->count();
-    for (int i = 1; i < nbColumn; ++i) {
-        act = menu.addAction(model()->headerData(i, Qt::Horizontal).toString());
-        act->setCheckable(true);
-        act->setChecked(!header()->isSectionHidden(i));
-        act->setData(QVariant(i));
-        connect(act, &QAction::triggered, this, &FolderTreeView::slotHeaderContextMenuChangeHeader);
+    if (nbColumn > 1) {
+        menu.addSection(i18n("View Columns"));
+        for (int i = 1; i < nbColumn; ++i) {
+            act = menu.addAction(model()->headerData(i, Qt::Horizontal).toString());
+            act->setCheckable(true);
+            act->setChecked(!header()->isSectionHidden(i));
+            act->setData(QVariant(i));
+            connect(act, &QAction::triggered, this, &FolderTreeView::slotHeaderContextMenuChangeHeader);
+        }
     }
 
     menu.addSection(i18n("Icon Size"));
@@ -498,12 +500,12 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
     // parameter (kept in the config file for kmail)
     const int result
         = KMessageBox::questionYesNo(
-        const_cast<FolderTreeView *>(this),
-        i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
-        i18n("Go to Next Unread Message"),
-        KGuiItem(i18n("Go To")),
-        KGuiItem(i18n("Do Not Go To")),         // defaults
-        QStringLiteral(":kmail_AskNextFolder"), nullptr);
+              const_cast<FolderTreeView *>(this),
+              i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
+              i18n("Go to Next Unread Message"),
+              KGuiItem(i18n("Go To")),
+              KGuiItem(i18n("Do Not Go To")),   // defaults
+              QStringLiteral(":kmail_AskNextFolder"), nullptr);
 
     return result == KMessageBox::Yes;
 }
@@ -520,7 +522,7 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &ind
         if (index.isValid()) {
             const Akonadi::Collection collection
                 = index.model()->data(
-                current, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                      current, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
             if (collection.isValid()) {
                 if (collection.statistics().unreadCount() > 0) {
@@ -570,8 +572,8 @@ Akonadi::Collection FolderTreeView::currentFolder() const
     if (current.isValid()) {
         const Akonadi::Collection collection
             = current.model()->data(
-            current,
-            Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                  current,
+                  Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         return collection;
     }
     return Akonadi::Collection();
