@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -70,17 +70,17 @@ public:
 
     QString filter;
     QString oldFilterStr;
-    Akonadi::StatisticsProxyModel *filterModel;
-    FolderTreeView *folderTreeView;
-    Akonadi::QuotaColorProxyModel *quotaModel;
-    FolderTreeWidgetProxyModel *readableproxy;
-    EntityCollectionOrderProxyModel *entityOrderProxy;
-    QLineEdit *filterFolderLineEdit;
+    Akonadi::StatisticsProxyModel *filterModel = nullptr;
+    FolderTreeView *folderTreeView = nullptr;
+    Akonadi::QuotaColorProxyModel *quotaModel = nullptr;
+    FolderTreeWidgetProxyModel *readableproxy = nullptr;
+    EntityCollectionOrderProxyModel *entityOrderProxy = nullptr;
+    QLineEdit *filterFolderLineEdit = nullptr;
     QPointer<Akonadi::ETMViewStateSaver> saver;
     QStringList expandedItems;
     QString currentItem;
-    QLabel *label;
-    bool dontKeyFilter;
+    QLabel *label = nullptr;
+    bool dontKeyFilter = false;
 };
 
 FolderTreeWidget::FolderTreeWidget(
@@ -113,11 +113,15 @@ FolderTreeWidget::FolderTreeWidget(
     d->quotaModel = new Akonadi::QuotaColorProxyModel(this);
     d->quotaModel->setSourceModel(KernelIf->collectionModel());
 
-    d->filterModel = new Akonadi::StatisticsProxyModel(this);
-    d->filterModel->setSourceModel(d->quotaModel);
+    if (!(options & HideStatistics)) {
+        d->filterModel = new Akonadi::StatisticsProxyModel(this);
+        d->filterModel->setSourceModel(d->quotaModel);
+    }
 
     d->readableproxy = new FolderTreeWidgetProxyModel(this, optReadableProxy);
-    d->readableproxy->setSourceModel(d->filterModel);
+    d->readableproxy->setSourceModel((options & HideStatistics)
+                                     ? static_cast<QAbstractItemModel *>(d->quotaModel)
+                                     : static_cast<QAbstractItemModel *>(d->filterModel));
     d->readableproxy->addContentMimeTypeInclusionFilter(KMime::Message::mimeType());
 
     connect(d->folderTreeView, &FolderTreeView::changeTooltipsPolicy, this, &FolderTreeWidget::slotChangeTooltipsPolicy);
@@ -129,6 +133,7 @@ FolderTreeWidget::FolderTreeWidget(
     //Order proxy
     d->entityOrderProxy = new EntityCollectionOrderProxyModel(this);
     d->entityOrderProxy->setSourceModel(d->readableproxy);
+    d->entityOrderProxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
     KConfigGroup grp(KernelIf->config(), "CollectionTreeOrder");
     d->entityOrderProxy->setOrderConfig(grp);
     d->folderTreeView->setModel(d->entityOrderProxy);
@@ -178,7 +183,7 @@ void FolderTreeWidget::slotFilterFixedString(const QString &text)
         d->folderTreeView->expandAll();
     }
     d->oldFilterStr = text;
-    d->readableproxy->setFilterFolder(text);
+    d->entityOrderProxy->setFilterWildcard(text);
 }
 
 void FolderTreeWidget::disableContextMenuAndExtraColumn()
@@ -239,7 +244,7 @@ Akonadi::Collection::List FolderTreeWidget::selectedCollections() const
         if (index.isValid()) {
             const Akonadi::Collection collection
                 = index.model()->data(
-                index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                      index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (collection.isValid()) {
                 collections.append(collection);
             }
@@ -301,10 +306,14 @@ void FolderTreeWidget::changeToolTipsPolicyConfig(ToolTipDisplayPolicy policy)
     switch (policy) {
     case DisplayAlways:
     case DisplayWhenTextElided: //Need to implement in the future
-        d->filterModel->setToolTipEnabled(true);
+        if (d->filterModel) {
+            d->filterModel->setToolTipEnabled(true);
+        }
         break;
     case DisplayNever:
-        d->filterModel->setToolTipEnabled(false);
+        if (d->filterModel) {
+            d->filterModel->setToolTipEnabled(false);
+        }
     }
     d->folderTreeView->setTooltipsPolicy(policy);
 }
@@ -354,7 +363,7 @@ void FolderTreeWidget::applyFilter(const QString &filter)
         ? i18n("You can start typing to filter the list of folders.")
         : i18n("Path: (%1)", filter));
 
-    d->readableproxy->setFilterFolder(filter);
+    d->entityOrderProxy->setFilterWildcard(filter);
     d->folderTreeView->expandAll();
     QAbstractItemModel *model = d->folderTreeView->model();
     QModelIndex current = d->folderTreeView->currentIndex();
@@ -402,13 +411,11 @@ bool FolderTreeWidget::eventFilter(QObject *o, QEvent *e)
             }
             applyFilter(d->filter);
             return false;
-            break;
         }
         case Qt::Key_Delete:
             d->filter.clear();
             applyFilter(d->filter);
             return false;
-            break;
         default:
         {
             const QString s = ke->text();
