@@ -15,8 +15,8 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef MAILCOMMON_SEARCH_SEARCHENCRYPTIONRULE_H_
-#define MAILCOMMON_SEARCH_SEARCHENCRYPTIONRULE_H_
+#ifndef MAILCOMMON_SEARCH_SEARCHRULEENCRYPTION_H_
+#define MAILCOMMON_SEARCH_SEARCHRULEENCRYPTION_H_
 
 #include "searchpattern.h"
 
