@@ -17,8 +17,6 @@
 
 #include <kactioncollection.h>
 #include <QDialog>
-#include <KLocalizedString>
-#include <KConfigGroup>
 #include <QVBoxLayout>
 #include <QPushButton>
 #include <QDialogButtonBox>
@@ -30,16 +28,16 @@ SnippetDialog::SnippetDialog(KActionCollection *actionCollection, bool inGroupMo
     , mActionCollection(actionCollection)
 {
     mUi = new Ui::SnippetDialog;
+    QWidget *mainWidget = new QWidget(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    mainLayout->addWidget(mainWidget);
+
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &SnippetDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SnippetDialog::reject);
-
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->addWidget(mainWidget);
     mainLayout->addWidget(buttonBox);
     mUi->setupUi(mainWidget);
 
@@ -47,7 +45,7 @@ SnippetDialog::SnippetDialog(KActionCollection *actionCollection, bool inGroupMo
     mOkButton->setEnabled(false);
 
     connect(mUi->nameEdit, &KLineEdit::textChanged, this, &SnippetDialog::slotTextChanged);
-    connect(mUi->groupBox, static_cast<void (KComboBox::*)(const QString &)>(&KComboBox::currentIndexChanged), this, &SnippetDialog::slotGroupChanged);
+    connect(mUi->groupBox, QOverload<const QString &>::of(&KComboBox::currentIndexChanged), this, &SnippetDialog::slotGroupChanged);
 
     mUi->snippetText->setMinimumSize(500, 300);
 
@@ -117,10 +115,12 @@ void SnippetDialog::slotTextChanged()
 
 bool SnippetDialog::snippetIsValid() const
 {
-    if (mUi->groupWidget->isVisible()) {
-        return !mUi->nameEdit->text().trimmed().isEmpty()
-               && !mUi->groupBox->currentText().trimmed().isEmpty();
+    if (mUi->nameEdit->text().trimmed().isEmpty()) {
+        return false;
     } else {
-        return !mUi->nameEdit->text().trimmed().isEmpty();
+        if (mUi->groupWidget->isVisible()) {
+            return !mUi->groupBox->currentText().trimmed().isEmpty();
+        }
     }
+    return true;
 }
